<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ja" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>情報</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>カテゴリ:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Torrent を開始する</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>ハッシュチェックを省略する</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>サブフォルダーを作成</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent 管理モード:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>カテゴリなし</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>カテゴリの追加...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>カテゴリの削除</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>未使用のカテゴリを削除</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrent の再開</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrent の停止</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrent の削除</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新規カテゴリ</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>カテゴリの編集...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>qBittorrent の終了</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>1 行に 1 リンクを入力してください</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>全体のアップロード速度制限は 0 より大きいか無効にしなければなりません。</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>全体のダウンロード速度制限は 0 より大きいか無効にしなければなりません。</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>代替アップロード速度制限は 0 より大きいか無効にしなければなりません。</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>代替ダウンロード速度制限は 0 より大きいか無効にしなければなりません。</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>最大アクティブダウンロード数は 1 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>最大アクティブアップロード数は 1 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>最大アクティブ Torrent 数は 1 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>最大接続数は 0 より大きいか無効でなくてはなりません。</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Torrent ごとの最大接続数は 0 より大きいか無効でなくてはなりません。</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>最大アップロートスロット数は 0 より大きいか無効でなくてはなりません。</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>プログラム設定の保存ができません。qBittorrent はおそらく通信可能状態にありません。</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: Freenode 上で #qbittorrent</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>共有比は 0 から 9998 の間でなければなりません。</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>シード時間制限は 0 から 525600 分の間でなければなりません。</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>着信接続に使用するポートは 1 から 65535 の間でなくてはなりません。</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web UI に使用するポートは 1 から 65535 の間でなくてはなりません。</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>ログインできません。おそらく qBittorrent から到達できません。</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>ユーザー名またはパスワーが正しくありません。</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>ログイン</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>オリジナルの作者</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Torrent のアップロード</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>ファイルの保存場所:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>フォルダーをここに入力してください</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>詳しい情報</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>SSL 証明書について</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>場所の設定</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>アップロード速度制限</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>ダウンロード速度制限</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Torrent 名の変更</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>その他...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>月曜日</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>火曜日</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>水曜日</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>木曜日</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>金曜日</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>土曜日</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>日曜日</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Torrent を URL またはマグネットリンクからダウンロードします</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>ローカルの Torrent をアップロード</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>選択された Torrent を転送リストから削除しますか?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent クライアントと通信できません</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>全体のアップロードスロット数制限は 0 より大きくするか無効にしなければなりません。</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>不正なカテゴリ名:\nカテゴリ名に特殊文字は使用しないでください。</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>カテゴリを作成できません</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>アップロード速度しきい値は 0 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>空きスペース: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrent 非活動時間は 0 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>保存管理</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>ダウンロード速度しきい値は 0 より大きくしなければなりません。</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent を終了しました</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>オプション...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>再開</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>最低優先度</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>最高優先度</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>優先度を下げる</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>優先度を上げる</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>トップツールバー</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>ステータスバー</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>タイトルバーに速度を表示</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>寄付!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>すべて再開</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計情報</translation>
    </message>
    <message>
        <source>About</source>
        <translation>qBittorrent について</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>すべて停止</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Torrent ファイルの追加...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Torrent リンクの追加...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>全体のアップロード速度上限</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>全体のダウンロード速度上限</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>qBittorrent を終了しますか?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>代替速度制限</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>検索エンジン</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Torrent リストをフィルター...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>転送</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>ユーザーインターフェースの言語:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>ダウンロード完了時にメールで通知する</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Torrent 完了時に外部プログラムを実行する</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP フィルタリング</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>代替速度制限を使用するスケジュール</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent キュー</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>指定シード時間に達するまでシードする</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>新しいダウンロードに以下のトラッカーを自動追加する:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>ウェブユーザーインターフェース (遠隔操作)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP アドレス:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>サーバードメイン:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTP でなく HTTPS を使用する</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>ローカルホストではクライアントの認証を行わない</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>ホワイトリストに登録された IP サブネットのクライアントは認証を行わない</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>ダイナミックドメイン名を更新する</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>未完了の Torrent の格納先:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>.torrent ファイルの保存先:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>ダウンロードが完了した .torrent ファイルのコピー先:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>すべてのファイルに対して事前にディスクスペースを割り当てる</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>未完了のファイル名に拡張子 .!qB を付加する</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>自動的に Torrent を追加するフォルダー:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP サーバー:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>このサーバーではセキュアな接続 (SSL) が必要</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>認証</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>有効なプロトコル:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP および μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>待ち受けポート</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>着信接続で使用するポート:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>ルーターからのポート転送に UPnP / NAT-PMP を使用する</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>起動時に毎回異なるポートを使用する</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>接続制限</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Torrent あたりの最大接続数:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>全体の最大接続数:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Torrent あたりの最大アップロードスロット数:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>全体の最大アップロードスロット数:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>プロキシサーバー</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>種類:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(なし)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>ホスト:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>ポート:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>ピアとの接続にプロキシを使用する</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>プロキシでサポートされていない接続は無効にする</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Torrent に対してのみプロキシを利用する</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>フィルターパス (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>手動でアクセス禁止にした IP アドレス...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>トラッカーにも適用する</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>全体の速度制限</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>アップロード:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>ダウンロード:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>代替速度制限</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>開始:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>終了:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>曜日:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>毎日</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>平日</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>週末</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>速度制限設定</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>トランスポートオーバーヘッドにも制限を適用する</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>速度制限を µTP プロトコルにも適用する</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>プライバシー</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>より多くのピアを見つけるため DHT (分散ネットワーク) を有効にする</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>より多くのピアを見つけるためにピア交換 (PeX) を有効にする</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>より多くのピアを見つけるためにローカルピア検出 (LSD) を有効にする</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>暗号化モード:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>暗号化を許可</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>暗号化を強制</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>暗号化しない</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>匿名モードを有効にする</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>最大アクティブダウンロード数:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>最大アクティブアップロード数:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>最大アクティブ Torrent 数:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>遅いトレントはカウントしない</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>共有比上限</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>指定共有比に達するまでシードする</translation>
    </message>
    <message>
        <source>then</source>
        <translation>達したら</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>停止する</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>削除する</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>ルーターからのポート転送に UPnP / NAT-PMP を使用する</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>証明書:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>公開鍵:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>登録</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>ドメイン名:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>サポートパラメーター (大文字小文字を区別):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrent 名</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: カテゴリ</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: タグ (カンマ区切り)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: コンテンツパス (Torrent 内ファイルのルート)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: ルートパス (最初の Torrent のパス)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: 保存パス</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: ファイル数</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrent サイズ (バイト)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: 現在のトラッカー</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: 情報ハッシュ</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>ヒント: パラメーターに空白が含まれるときはダブルクオーテーションで括ってください (例: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web UI のユーザー名は 3 文字以上にしてください。</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web UI のパスワードは 6 文字以上にしてください。</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>クリックジャッキング保護を有効にする</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>クロスサイトリクエストフォージェリ (CSRF) 保護を有効にする</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>その後 .torrent ファイルを削除</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>ダウンロード速度しきい値:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>アップロード速度しきい値:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>現在のパスワードを変更</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>独自の Web UI を使用する</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>デフォルトの保存パス:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>独自の Web UI ファイルの場所は空白のままにはできません。</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>ダウンロードを自動で開始しない</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Torrent を手動モードに切り換える</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Torrent のカテゴリが変更されたとき:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>影響を受ける Torrent を移動</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>LAN 上のピアに対しても速度制限を適用する</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 で無制限</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Torrent を移動</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>デフォルトの保存パスが変更されたとき:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Host ヘッダー検証を有効にする</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>カテゴリの保存パスが変更されたとき:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>複数ファイルの Torrent にはサブフォルダーを作成する</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>影響を受ける Torrent を手動モードに切り換える</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>ファイルの場所:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrent 非活動時間:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>デフォルトの Torrent 管理モード:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Torrent を追加したとき</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>フラグ</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>クライアント</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>進行状況</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>DL 速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>UP 速度</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>DL 量</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>UP 量</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>関連性</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>国</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>通常</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>高い</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>最高</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>全般</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>トラッカー</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>ピア</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP ソース</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>コンテンツ</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>ダウンロード量:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>転送</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>動作時間:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>予想残り時間:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>アップロード量:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>シード数:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>ダウンロード速度:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>アップロード速度:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>ピア数:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>ダウンロード速度制限:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>アップロード速度制限:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>破棄:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>接続数:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>共有比:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>次のアナウンスまで:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>最後に完了ファイルを確認した日時:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>全体サイズ:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>ピース数:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>作成:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>追加日時:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>完了日時:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>作成日時:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent ハッシュ:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>保存パス:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (保有 %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 このセッション)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (最大 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (合計 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (平均 %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>ダウンロード制限:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>アップロード制限:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>監視フォルダー</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>保存先</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>監視フォルダー</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>デフォルトの保存先</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>統計情報</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>利用者統計</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>キャッシュ統計</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>読み込みキャッシュヒット:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>平均キュー待ち時間:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>接続ピア数:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>総合共有比:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>総合ダウンロード量:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>セッション破棄:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>総合アップロード量:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>全バッファサイズ:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>性能統計</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>待ち I/O ジョブ数:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>書き込みキャッシュオーバーロード:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>読み込みキャッシュオーバーロード:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>総キューサイズ:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 ノード</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>すべて (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>ダウンロード中 (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>シード中 (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>完了 (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>再開 (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>停止中 (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>動作中 (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>非動作中 (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>エラー (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>すべて (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>ダウンロード中 (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>シード中 (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>完了 (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>停止中 (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>再開 (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>動作中 (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>非動作中 (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>エラー (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>進行状況</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>ダウンロード優先度</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>残り</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>可用性</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>名前</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>進行状況</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>状態</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>シード</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>ピア</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>DL 速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>UP 速度</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>共有比</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>予想残り時間</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>タグ</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>追加日時</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>完了日時</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>トラッカー</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>DL 速度上限</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>UP 速度上限</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>ダウンロード量</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>アップロード 量</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>セッション内ダウンロード量</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>セッション内アップロード量</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>残りダウンロード量</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>動作時間</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>保存先</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>完了</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>共有比上限</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>最後に完了ファイルを確認した日時</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>最終動作</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>合計サイズ</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>ピア</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>トラッカー URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>更新中...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>稼働中</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>まだ接触していません</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>シード</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>稼働していません</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>トラッカー URL をコピー</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>新規トラッカーを追加...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>トラッカー URK の編集...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>トラッカーの編集</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>リーチャー</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>トラッカーを削除</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>トラッカーの追加ダイアログ</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>追加するトラッカーを入力してください (1行に1トラッカー):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 前</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>割り当て中</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>移動中</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] シード中</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>シード中</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>待機中</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] ダウンロード中</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>メタデータダウンロード中</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>チェック中</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>ファイルがありません</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>チェック待ち</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>ダウンロード中</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>再開データのチェック中</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>ダウンロード待ち</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>カテゴリ</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent ダウンロード速度制限</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent アップロード速度制限</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>再開</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>強制再開</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>停止</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>削除</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>共有比上限...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>アップロード速度制限...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>ダウンロード速度制限...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>上げる</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>下げる</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>先頭へ</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>最後へ</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>場所の移動...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>名前をコピー</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>ハッシュをコピー</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>先頭と最後のピースを先にダウンロード</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>自動 Torrent 管理</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>新規...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>リセット</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>優先度</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>強制再チェック</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>マグネットリンクをコピー</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>スーパーシードモード</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>名前の変更...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>シーケンシャルにダウンロード</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>強制再チェック</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新規カテゴリ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>場所</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>新しい名前</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>場所の指定</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>強制再アナウンス</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>カテゴリの編集</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>保存パス</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent: アップロード量/ダウンロード量 比率制限</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>全体の共有比上限を使用</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>共有比上限なし</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>共有比上限を指定</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>共有比</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Qt ツールキットと libtorrent-rasterbar を使用し C++ で書かれた高度な BitTorrent クライアントです。</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>ホームページ:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>フォーラム:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>バグトラッカー:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>削除の確認</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>ハードディスク上のファイルも削除する</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>削除の確認 - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>URLからダウンロード</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Torrent リンクの追加</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1時間 %2分</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1日 %2時間</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>不明</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 分</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 分</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>保存パスが空です</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>プラグインパス:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL またはローカルディレクトリ</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>プラグインのインストール</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>シード数:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>全プラグイン</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>サイズ:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>検索プラグイン...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>全カテゴリ</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>検索対象:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>説明ページの URL をコピー</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>説明ページへ移動</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>検索結果 (表示中</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Torrent 名のみ</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>有効なもののみ</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>/</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>すべて</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>アンインストール</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>新規プラグインのインストール</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>新しい検索プラグインはここから入手できます:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>インストールされている検索プラグイン:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>警告: これら検索エンジンから Torrent をダウンロードする際は、あなたの国の法を遵守していることを必ず確認してください。</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>更新をチェック</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>検索エンジン</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>リーチャー</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>検索エンジン</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>シーダー</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
</context>
</TS>